@@ -453,7 +453,7 @@ NEOERR *cgi_text_html_strfunc(unsigned char *str, unsigned char **ret);
 NEOERR *cgi_html_strip_strfunc(unsigned char *str, unsigned char **ret);
 NEOERR *cgi_html_escape_strfunc(unsigned char *str, unsigned char **ret);
 NEOERR *cgi_js_escape (unsigned char *buf, unsigned char **esc);
-void cgi_html_ws_strip_level(STRING *str, int level);
+void cgi_html_ws_strip(STRING *str, int level);
 NEOERR *cgi_register_strfuncs(CSPARSE *cs);
 
 /* internal use only */
